%bcond_with check
%bcond_with cppunit

Summary:        C bindings for subunit
Name:           subunit
Version:        1.4.2
Release:        6%{?dist}
License:        Apache-2.0 OR BSD-3-Clause
URL:            https://launchpad.net/subunit
Source0:        https://launchpad.net/subunit/trunk/%{version}/+download/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++ libtool make pkgconfig
BuildRequires:  perl-generators perl(ExtUtils::MakeMaker)
BuildRequires:  pkgconfig(cppunit) pkgconfig(check)
BuildRequires:  python3-devel %{py3_dist docutils} %{py3_dist pip}
BuildRequires:  %{py3_dist setuptools} %{py3_dist wheel}
%if %{with check}
BuildRequires:  %{py3_dist extras} %{py3_dist testscenarios} %{py3_dist hypothesis}
BuildRequires:  %{py3_dist fixtures} %{py3_dist testtools} >= 0.9.34
%endif

%description
Subunit C bindings.  See the python-subunit package for test processing
functionality.

%package devel
Summary:        Header files for developing C applications that use subunit
Requires:       %{name} = %{version}-%{release}

%description devel
Header files and libraries for developing C applications that use subunit.

%if %{with cppunit}
%package cppunit
Summary:        Subunit integration into cppunit
Requires:       %{name} = %{version}-%{release}

%description cppunit
Subunit integration into cppunit.

%package cppunit-devel
Summary:        Header files for applications that use cppunit and subunit
Requires:       %{name}-cppunit = %{version}-%{release}
Requires:       %{name}-devel = %{version}-%{release}
Requires:       cppunit-devel

%description cppunit-devel
Header files and libraries for developing applications that use cppunit
and subunit.
%endif

%package perl
Summary:        Perl bindings for subunit
Requires:       perl(:MODULE_COMPAT_%{perl_version})
BuildArch:      noarch

%description perl
Subunit perl bindings.  See the python-subunit package for test
processing functionality.

%package shell
Summary:        Shell bindings for subunit
BuildArch:      noarch

%description shell
Subunit shell bindings.  See the python-subunit package for test
processing functionality.

%package -n python3-%{name}
Summary:        Streaming protocol for test results
License:        (Apache-2.0 OR BSD-3-Clause) AND MIT
Provides:       bundled(python3-iso8601) = 0.1.4
BuildArch:      noarch

%description -n python3-%{name}
Subunit is a streaming protocol for test results.  The protocol is a
binary encoding that is easily generated and parsed.  By design all the
components of the protocol conceptually fit into the xUnit TestCase ->
TestResult interaction.

Subunit comes with command line filters to process a subunit stream and
language bindings for python, C, C++ and shell.  Bindings are easy to
write for other languages.

A number of useful things can be done easily with subunit:
- Test aggregation: Tests run separately can be combined and then
  reported/displayed together.  For instance, tests from different
  languages can be shown as a seamless whole.
- Test archiving: A test run may be recorded and replayed later.
- Test isolation: Tests that may crash or otherwise interact badly with
  each other can be run separately and then aggregated, rather than
  interfering with each other.
- Grid testing: subunit can act as the necessary serialization and
  deserialization to get test runs on distributed machines to be
  reported in real time.

%package -n python3-%{name}-test
Summary:        Test code for the python 3 subunit bindings
Requires:       python3-%{name} = %{version}-%{release}
Requires:       %{name}-filters = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{name}-test
%{summary}.

%package filters
Summary:        Command line filters for processing subunit streams
Requires:       python3-%{name} = %{version}-%{release}
Requires:       python3-gobject
Requires:       gtk3 >= 3.20
Requires:       libnotify >= 0.7.7
Requires:       %{py3_dist junitxml}
BuildArch:      noarch

%description filters
Command line filters for processing subunit streams.

%package static
Summary:        Static C library for subunit
Requires:       %{name}-devel = %{version}-%{release}

%description static
Subunit C bindings in a static library, for building statically linked
test cases.

%prep
%autosetup -p1

sed "/^tests_LDADD/ilibcppunit_subunit_la_LIBADD = -lcppunit libsubunit.la\n" \
    -i Makefile.am

for fil in $(grep -Frl "%{_bindir}/env python"); do
  sed -ri.orig 's,%{_bindir}/env python3?,%{python3},' $fil
  touch -r ${fil}.orig ${fil}
  rm -f ${fil}.orig
done

%build
export INSTALLDIRS=perl
export PYTHON=%{python3}
%configure --enable-shared --enable-static

sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i libtool

%make_build
%pyproject_wheel

%install
%pyproject_install
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/run.py
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/tests/sample-script.py
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/tests/sample-two-script.py

%make_install pkgpython_PYTHON='' INSTALL="%{_bindir}/install -p"

mkdir -p %{buildroot}%{_sysconfdir}/profile.d
cp -p shell/share/%{name}.sh %{buildroot}%{_sysconfdir}/profile.d
rm -f %{buildroot}%{_libdir}/*.la

perl_majver=$(cut -d. -f-2 <<< %{perl_version})
mkdir -p %{buildroot}%{perl_vendorlib}
mv %{buildroot}%{perl_privlib}/$perl_majver/Subunit* %{buildroot}%{perl_privlib}
rm -fr %{buildroot}%{perl_privlib}/$perl_majver %{buildroot}%{perl_archlib}

chmod 0755 %{buildroot}%{_bindir}/subunit-diff
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/filter_scripts/*.py
chmod 0644 %{buildroot}%{python3_sitelib}/%{name}/filter_scripts/__init__.py
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/tests/sample-script.py
chmod 0755 %{buildroot}%{python3_sitelib}/%{name}/tests/sample-two-script.py

touch -r c/include/%{name}/child.h %{buildroot}%{_includedir}/%{name}/child.h
touch -r perl/subunit-diff %{buildroot}%{_bindir}/subunit-diff

%if %{with cppunit}
touch -r c++/SubunitTestProgressListener.h \
      %{buildroot}%{_includedir}/%{name}/SubunitTestProgressListener.h
%else
rm -f %{buildroot}%{_includedir}/%{name}/SubunitTestProgressListener.h
rm -f %{buildroot}%{_libdir}/libcppunit_%{name}.so.0*
rm -f %{buildroot}%{_libdir}/libcppunit_%{name}.so
rm -f %{buildroot}/c++/README
rm -f %{buildroot}%{_libdir}/pkgconfig/libcppunit_%{name}.pc
%endif

%if %{with check}
%check
export LD_LIBRARY_PATH=$PWD/.libs
export PYTHON=%{python3}
make check
%endif

%files
%license Apache-2.0 BSD COPYING
%doc NEWS README.rst
%{_libdir}/lib%{name}.so.0*

%files devel
%doc c/README
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/child.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc

%if %{with cppunit}
%files cppunit
%{_libdir}/libcppunit_%{name}.so.0*

%files cppunit-devel
%doc c++/README
%{_includedir}/%{name}/SubunitTestProgressListener.h
%{_libdir}/libcppunit_%{name}.so
%{_libdir}/pkgconfig/libcppunit_%{name}.pc
%endif

%files perl
%license Apache-2.0 BSD COPYING
%{_bindir}/%{name}-diff
%{perl_privlib}/Subunit/
%{perl_privlib}/Subunit.pm

%files shell
%doc shell/README
%license Apache-2.0 BSD COPYING
%config(noreplace) %{_sysconfdir}/profile.d/%{name}.sh

%files -n python3-%{name}
%license Apache-2.0 BSD COPYING
%{python3_sitelib}/%{name}/
%{python3_sitelib}/python_%{name}-%{version}.dist-info/
%exclude %{python3_sitelib}/%{name}/tests/

%files -n python3-%{name}-test
%{python3_sitelib}/%{name}/tests/

%files static
%{_libdir}/*.a

%files filters
%{_bindir}/subunit*
%{_bindir}/tap2subunit
%exclude %{_bindir}/%{name}-diff

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.2-6
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.2-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.2-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.2-3
- Rebuilt for OpenCloudOS Stream 23

* Tue Feb 21 2023 Shuo Wang <abushwang@tencent.com> - 1.4.2-2
- remove unused buildrequires

* Wed Nov 23 2022 Xiaojie Chen <jackxjchen@tencent.com> - 1.4.2-1
- Initial build
